Pinax Submissions
=================

.. image:: http://slack.pinaxproject.com/badge.svg
   :target: http://slack.pinaxproject.com/

.. image:: https://img.shields.io/travis/pinax/pinax-submissions.svg
   :target: https://travis-ci.org/pinax/pinax-submissions

.. image:: https://img.shields.io/coveralls/pinax/pinax-submissions.svg
   :target: https://coveralls.io/r/pinax/pinax-submissions

.. image:: https://img.shields.io/pypi/dm/pinax-submissions.svg
   :target:  https://pypi.python.org/pypi/pinax-submissions/

.. image:: https://img.shields.io/pypi/v/pinax-submissions.svg
   :target:  https://pypi.python.org/pypi/pinax-submissions/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target:  https://pypi.python.org/pypi/pinax-submissions/


Pinax
------

Pinax is an open-source platform built on the Django Web Framework. It is an ecosystem of reusable Django apps, themes, and starter project templates.
This collection can be found at http://pinaxproject.com.

This app was developed as part of the Pinax ecosystem but is just a Django app and can be used independently of other Pinax apps.

pinax-submissions
-------------------

pinax-submissions is an app for proposing and reviewing submissions.


Running the Tests
-------------------

::

   $ pip install detox
   $ detox


Documentation
---------------

The pinax-submissions documentation is currently under construction. If you would like to help us write documentation, please join our Pinax Project Slack channel and let us know!
The Pinax documentation is available at http://pinaxproject.com/pinax/.


Code of Conduct
----------------

In order to foster a kind, inclusive, and harassment-free community, the Pinax Project has a code of conduct, which can be found here  http://pinaxproject.com/pinax/code_of_conduct/.


Pinax Project Blog and Twitter
--------------------------------

For updates and news regarding the Pinax Project, please follow us on Twitter at @pinaxproject and check out our blog http://blog.pinaxproject.com.
